summaryrefslogtreecommitdiff
path: root/include/lpc.h
diff options
context:
space:
mode:
authorRandall Spangler <rspangler@chromium.org>2012-03-01 15:18:56 -0800
committerRandall Spangler <rspangler@chromium.org>2012-03-01 15:22:14 -0800
commit9a60f37c8da8a61eb03d940f08f177a287b8f5ee (patch)
tree9fd17284ededb1921c9a1637c363546a8381c841 /include/lpc.h
parent5cd0f292e9c769264c5fa1f0fe262c910a9194ec (diff)
downloadchrome-ec-9a60f37c8da8a61eb03d940f08f177a287b8f5ee.tar.gz
Refactor LPC status / result codes
This is necessary to support SCI/SMI events. Note that this breaks compatibility with previous ectool builds - and probably also breaks flashrom support. Signed-off-by: Randall Spangler <rspangler@chromium.org> BUG=chrome-os-partner:8253 TEST='ectool hello' and 'ectool flashinfo' still work and 'ectool usbchargemode 3 1' fails with error 2 Change-Id: If39e5b6e7cdcec1b5ec765594e8492925b430b10
Diffstat (limited to 'include/lpc.h')
-rw-r--r--include/lpc.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/include/lpc.h b/include/lpc.h
index b616659300..074b9f6f2b 100644
--- a/include/lpc.h
+++ b/include/lpc.h
@@ -29,10 +29,9 @@ uint8_t *lpc_get_host_range(int slot);
* any time, and the host can read it at any time. */
uint8_t *lpc_get_memmap_range(void);
/* Sends a response to a host command. The bottom 4 bits of <status>
* are sent in the status byte. <slot> is 0 for kernel-originated
* commands, 1 for usermode-originated commands. */
-void lpc_send_host_response(int slot, int status);
+void lpc_send_host_response(int slot, int result);
/* Return true if the TOH is still set */
int lpc_keyboard_has_char(void);
@@ -29,10 +29,9 @@ uint8_t *lpc_get_host_range(int slot);
* any time, and the host can read it at any time. */
uint8_t *lpc_get_memmap_range(void);
-/* Sends a response to a host command. The bottom 4 bits of <status>
- * are sent in the status byte. <slot> is 0 for kernel-originated
+/* Sends a result code to a host command. <slot> is 0 for kernel-originated
* commands, 1 for usermode-originated commands. */